@@ -57,7 +57,7 @@ namespace Rcpp{
 	        return (int) dims.size() ;
 	    }
 	    inline int prod() const {
-	        return std::accumulate( dims.begin(), dims.end(), 1, std::multiplies<int>() ) ;
+	        return std::accumulate( dims.begin(), dims.end(), static_cast<R_xlen_t>(1), std::multiplies<R_xlen_t>() );
 	    }
 
 	    inline reference operator[](int i){
