@@ -1,6 +1,6 @@
 // -*- mode: C++; c-indent-level: 4; c-basic-offset: 4; tab-width: 4 -*-
 //
-// rnbinom_mu.h: Rcpp R/C++ interface class library -- 
+// rnbinom_mu.h: Rcpp R/C++ interface class library --
 //
 // Copyright (C) 2010 - 2011 Douglas Bates, Dirk Eddelbuettel and Romain Francois
 //
@@ -25,33 +25,23 @@
 namespace Rcpp {
 	namespace stats {
 
-	    template <bool seed>
-		class NBinomGenerator_Mu : public ::Rcpp::Generator<seed,double> {
+
+		class NBinomGenerator_Mu : public ::Rcpp::Generator<double> {
 		public:
-	
-			NBinomGenerator_Mu( double siz_, double mu_ ) : 
+
+			NBinomGenerator_Mu( double siz_, double mu_ ) :
 				siz(siz_), lambda( mu_ / siz_ ) {}
-	
+
 			inline double operator()() const {
-				return ::Rf_rpois( ::Rf_rgamma( siz, lambda ) ) ; 
+				return ::Rf_rpois( ::Rf_rgamma( siz, lambda ) ) ;
 			}
-	
+
 		private:
 			double siz ;
 			double lambda ;
 		} ;
 	} // stats
 
-	// Please make sure you to read Section 6.3 of "Writing R Extensions"
-	// about the need to call GetRNGstate() and PutRNGstate() when using 
-	// the random number generators provided by R.
-	inline NumericVector rnbinom_mu( int n, double siz, double mu ){
-		if(!R_FINITE(siz) || !R_FINITE(mu) || siz <= 0 || mu < 0)
-			return NumericVector( n, R_NaN ) ;
-    
-		return NumericVector( n, stats::NBinomGenerator_Mu<false>( siz, mu ) ) ;
-	}
-
 } // Rcpp
 
 #endif
