@@ -1,8 +1,8 @@
-// -*- mode: C++; c-indent-level: 4; c-basic-offset: 4; tab-width: 8 -*-
+// -*- mode: C++; c-indent-level: 4; c-basic-offset: 4; indent-tabs-mode: nil; -*-
 //
 // misc.cpp: Rcpp R/C++ interface class library -- misc unit tests
 //
-// Copyright (C) 2013    Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2013 - 2015  Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -20,7 +20,7 @@
 // along with Rcpp.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <Rcpp.h>
-using namespace Rcpp ;
+using namespace Rcpp;
 using namespace std;
 #include <iostream>
 #include <fstream>
@@ -34,47 +34,47 @@ public:
 };
 
 // [[Rcpp::export]]
-SEXP symbol_(){
+SEXP symbol_() {
     return LogicalVector::create(
         Symbol( Rf_install("foobar") ) == Rf_install("foobar"),
         Symbol( Rf_mkChar("foobar") ) == Rf_install("foobar"),
         Symbol( Rf_mkString("foobar") ) == Rf_install("foobar"),
         Symbol( "foobar" ) == Rf_install("foobar")
-    ) ;
+    );
 }
 
 // [[Rcpp::export]]
-Symbol symbol_ctor(SEXP x){ return Symbol(x); }
+Symbol symbol_ctor(SEXP x) { return Symbol(x); }
 
 // [[Rcpp::export]]
-List Argument_(){
+List Argument_() {
     Argument x("x"), y("y");
     return List::create( x = 2, y = 3 );
 }
 
 // [[Rcpp::export]]
-int Dimension_const( SEXP ia ){
+int Dimension_const( SEXP ia ) {
     simple ss(ia);
-	return ss.nrow();
+        return ss.nrow();
 }
 
 // [[Rcpp::export]]
-SEXP evaluator_error(){
-    return Rcpp_eval( Rf_lang2( Rf_install("stop"), Rf_mkString( "boom" ) ) ) ;
+SEXP evaluator_error() {
+    return Rcpp_eval( Rf_lang2( Rf_install("stop"), Rf_mkString( "boom" ) ) );
 }
 
 // [[Rcpp::export]]
-SEXP evaluator_ok(SEXP x){
-    return Rcpp_eval( Rf_lang2( Rf_install("sample"), x ) ) ;
+SEXP evaluator_ok(SEXP x) {
+    return Rcpp_eval( Rf_lang2( Rf_install("sample"), x ) );
 }
 
 // [[Rcpp::export]]
-void exceptions_(){
-    throw std::range_error("boom") ;
+void exceptions_() {
+    throw std::range_error("boom");
 }
 
 // [[Rcpp::export]]
-LogicalVector has_iterator_( ){
+LogicalVector has_iterator_( ) {
     return LogicalVector::create(
         (bool)Rcpp::traits::has_iterator< std::vector<int> >::value,
         (bool)Rcpp::traits::has_iterator< std::list<int> >::value,
@@ -87,7 +87,7 @@ LogicalVector has_iterator_( ){
 }
 
 // [[Rcpp::export]]
-void test_rcout(std::string tfile, std::string teststring){
+void test_rcout(std::string tfile, std::string teststring) {
     // define and open testfile
     std::ofstream testfile(tfile.c_str());
 
@@ -108,8 +108,8 @@ void test_rcout(std::string tfile, std::string teststring){
 }
 
 // [[Rcpp::export]]
-LogicalVector na_proxy(){
-    CharacterVector s("foo") ;
+LogicalVector na_proxy() {
+    CharacterVector s("foo");
     return LogicalVector::create(
         NA_REAL    == NA,
         NA_INTEGER == NA,
@@ -130,29 +130,49 @@ LogicalVector na_proxy(){
         NA         == 12   ,
         NA         == "foo",
         NA         == s[0]
-        ) ;
+        );
 }
 
 // [[Rcpp::export]]
-StretchyList stretchy_list(){
-    StretchyList out ;
-    out.push_back( 1 ) ;
-    out.push_front( "foo" ) ;
-    out.push_back( 3.2 ) ;
+StretchyList stretchy_list() {
+    StretchyList out;
+    out.push_back( 1 );
+    out.push_front( "foo" );
+    out.push_back( 3.2 );
     return out;
 }
 
 // [[Rcpp::export]]
-StretchyList named_stretchy_list(){
-    StretchyList out ;
-    out.push_back( _["b"] = 1 ) ;
-    out.push_front( _["a"] = "foo" ) ;
-    out.push_back( _["c"] = 3.2 ) ;
+StretchyList named_stretchy_list() {
+    StretchyList out;
+    out.push_back( _["b"] = 1 );
+    out.push_front( _["a"] = "foo" );
+    out.push_back( _["c"] = 3.2 );
     return out;
 }
 
 // [[Rcpp::export]]
-void test_stop_variadic(){
-    stop( "%s %d", "foo", 3 ) ;    
+void test_stop_variadic() {
+    stop( "%s %d", "foo", 3 );
+}
+
+// [[Rcpp::export]]
+bool testNullableForNull(Nullable<NumericMatrix> M) {
+    return M.isNull();
+}
+
+// [[Rcpp::export]]
+bool testNullableForNotNull(Nullable<NumericMatrix> M) {
+    return M.isNotNull();
+}
+
+// [[Rcpp::export]]
+SEXP testNullableOperator(Nullable<NumericMatrix> M) {
+    return M;
+}
+
+// [[Rcpp::export]]
+SEXP testNullableGet(Nullable<NumericMatrix> M) {
+    return M.get();
 }
 
