@@ -1,6 +1,6 @@
 #!/usr/bin/r -t
 #
-# Copyright (C) 2010 - 2014  Dirk Eddelbuettel and Romain Francois
+# Copyright (C) 2010 - 2015  Dirk Eddelbuettel and Romain Francois
 #
 # This file is part of Rcpp.
 #
@@ -147,4 +147,25 @@ if (.runThisTest) {
         checkEquals( m, "foo 3" ) 
     }
 
+    test.NullableForNull <- function() {
+        M <- matrix(1:4, 2, 2)
+        checkTrue(   testNullableForNull(NULL) )
+        checkTrue( ! testNullableForNull(M) )
+    }
+    
+    test.NullableForNotNull <- function() {
+        M <- matrix(1:4, 2, 2)
+        checkTrue( ! testNullableForNotNull(NULL) )
+        checkTrue(   testNullableForNotNull(M) )
+    }
+
+    test.NullableAccessOperator <- function() {
+        M <- matrix(1:4, 2, 2)
+        checkEquals( testNullableOperator(M), M )
+    }
+    
+    test.NullableAccessGet <- function() {
+        M <- matrix(1:4, 2, 2)
+        checkEquals( testNullableGet(M), M )
+    }
 }
